@@ -11,7 +11,7 @@ def test_func(x):
     """
     rand_time = randint(0, 256) / 100.
     sleep(rand_time)
-    print "function :", x, ": sleeping", rand_time, "before exit"
+    print ("function :", x, ": sleeping", rand_time, "before exit")
     return [x ** x]
 
 
@@ -27,18 +27,18 @@ excepted = [[r ** r] for r in count_depth]
 # creation of a pool of 8 process
 tp = tp.TaskPool([], 8)
 
-print "Launching", count, "functions that will wait between 0 to 2.56s using", process, "processes"
+print ("Launching", count, "functions that will wait between 0 to 2.56s using", process, "processes")
 
 # launch
 for y in count_depth:
     tp.launch(test_func, y)
 
-print "All launched, waiting all to finish"
+print ("All launched, waiting all to finish")
 
 unres = [r for r in tp.get_unsorted_results()]
-print "All tasks done"
+print ("All tasks done")
 
 res = [r for r in tp.get_sorted_results()]
 
 if res == excepted:
-    print "results match the excepted"
\ No newline at end of file
+    print ("results match the excepted")
